@@ -1,8 +1,9 @@
+import io
+import os
+import json
 from uuid import uuid4
 from pathlib import Path
 from typing import List
-import io
-import json
 
 import numpy as np
 import xtgeo
@@ -225,7 +226,9 @@ per realization.
                     ]
                 ),
             )
-        return html.Div(id=self.ids("cube"))
+        return html.Div(
+            style={"visibility": "hidden"}, children=dcc.Dropdown(id=self.ids("cube"))
+        )
 
     @property
     def marginal_log_layout(self):
@@ -246,7 +249,10 @@ per realization.
                     ]
                 ),
             )
-        return html.Div(id=self.ids("marginal-log"))
+        return html.Div(
+            style={"visibility": "hidden"},
+            children=dcc.Dropdown(id=self.ids("marginal-log")),
+        )
 
     @property
     def intersection_option(self):
@@ -265,24 +271,19 @@ per realization.
             style=self.set_style(marginTop="20px"),
             children=[
                 html.Label("Intersection settings", style={"font-weight": "bold"}),
-                html.Div(
-                    style=self.set_grid_layout("1fr 1fr"),
-                    children=[
-                        html.Label("Sampling"),
-                        html.Label("Extension"),
-                        dcc.Input(
-                            id=self.ids("sampling"),
-                            debounce=True,
-                            type="number",
-                            value=self.sampling,
-                        ),
-                        dcc.Input(
-                            id=self.ids("nextend"),
-                            debounce=True,
-                            type="number",
-                            value=self.nextend,
-                        ),
-                    ],
+                html.Label("Sampling"),
+                dcc.Input(
+                    id=self.ids("sampling"),
+                    debounce=True,
+                    type="number",
+                    value=self.sampling,
+                ),
+                html.Label("Extension"),
+                dcc.Input(
+                    id=self.ids("nextend"),
+                    debounce=True,
+                    type="number",
+                    value=self.nextend,
                 ),
                 dcc.Checklist(id=self.ids("options"), options=options, value=value),
             ],
@@ -290,8 +291,7 @@ per realization.
 
     @property
     def map_layout(self):
-        return html.Div(
-            style=self.set_style(columns="2fr 1fr"),
+        return wcc.FlexBox(
             children=[
                 dcc.Dropdown(
                     id=self.ids("surface-name"),
@@ -324,10 +324,10 @@ per realization.
 
     @property
     def layout(self):
-        return html.Div(
-            style=self.set_style(columns="1fr 8fr"),
+        return wcc.FlexBox(
             children=[
                 html.Div(
+                    style={"flex": 1},
                     children=[
                         self.well_layout,
                         self.surface_names_layout,
@@ -339,7 +339,7 @@ per realization.
                 ),
                 html.Div(
                     id=self.ids("viz_wrapper"),
-                    style={"position": "relative"},
+                    style={"position": "relative", "flex": 8},
                     children=[
                         html.Div(wcc.Graph(id=self.ids("graph"))),
                         html.Div(
@@ -381,16 +381,6 @@ per realization.
             }
         return {**kwargs}
 
-    @staticmethod
-    def set_grid_layout(columns, **kwargs):
-        return {
-            "display": "grid",
-            "alignContent": "space-around",
-            "justifyContent": "space-between",
-            "gridTemplateColumns": f"{columns}",
-            **kwargs,
-        }
-
     def set_callbacks(self, app):
         @app.callback(
             [
@@ -422,7 +412,7 @@ per realization.
                 self.surfacefiles[self.surfacenames.index(name)]
                 for name in surfacenames
             ]
-            well = load_well(str(get_path(well)))
+            well = load_well(get_path(well))
             xsect = XSectionFigure(
                 well=well,
                 zmin=self.zmin,
@@ -444,7 +434,7 @@ per realization.
                 )
 
             if "show_seismic" in options:
-                cube = load_cube_data(str(get_path(cube)))
+                cube = load_cube_data(get_path(cube))
                 xsect.plot_cube(cube)
 
             xsect.plot_well(
@@ -550,10 +540,9 @@ per realization.
 def calculate_surface_statistics(
     realdf, ensemble, surfacefile, surfacefolder
 ) -> io.BytesIO:
-    real_paths = list(realdf[realdf["ENSEMBLE"] == ensemble]["RUNPATH"])
     fns = [
-        str(Path(Path(real_path) / Path(surfacefolder) / Path(surfacefile)))
-        for real_path in real_paths
+        os.path.join(real_path, surfacefolder, surfacefile)
+        for real_path in list(realdf[realdf["ENSEMBLE"] == ensemble]["RUNPATH"])
     ]
     surfaces = get_surfaces(fns)
     return io.BytesIO(
